/**
 * Copyright (c) 2020 Bubble, Inc.  All rights reserved.
 * For personal (non-commercial) use, see license: https://getbubblenow.com/bubble-license/
 */
package bubble.service.account;

import bubble.model.account.Account;
import bubble.model.bill.AccountPlan;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import lombok.Setter;
import lombok.experimental.Accessors;

import java.util.Optional;

@NoArgsConstructor @Accessors(chain=true)
public class SyncAccountNotification {

    @Getter @Setter private String accountUuid;
    @Getter @Setter private Optional<String> hashedPassword = Optional.empty();
    @Getter @Setter private Optional<AccountPlan> accountPlan = Optional.empty();
    @Getter @Setter private Optional<String> forceDeletedAccountPlanName = Optional.empty();

    public SyncAccountNotification(@NonNull final Account account) {
        this.accountUuid = account.getUuid();
        this.hashedPassword = Optional.of(account.getHashedPassword().getHashedPassword());
    }

    public SyncAccountNotification(@NonNull final String accountUuid, @NonNull final AccountPlan accountPlan) {
        this.accountUuid = accountUuid;
        this.accountPlan = Optional.of(accountPlan);
    }

    public SyncAccountNotification(@NonNull final String accountUuid, @NonNull final String forceDeletedPlanUuid) {
        this.accountUuid = accountUuid;
        this.forceDeletedAccountPlanName = Optional.of(forceDeletedPlanUuid);
    }
}
